#
# spec file for package stlink
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550 && 0%{?sle_version} <= 150300
# systemd-rpm-macros is wrong in 15.3 and below
%define _modprobedir /lib/modprobe.d
%endif
%global modprobe_d_files stlink_v1.conf

%define         sover 1

Name:           stlink
Version:        1.7.0
Release:        2.8
Summary:        STM32 discovery line linux programmer
License:        BSD-3-Clause
Group:          Development/Tools/Debuggers
URL:            https://github.com/stlink-org/stlink/
Source0:        https://github.com/stlink-org/stlink/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gtk3-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
Requires:       udev

%description
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package        gui
Summary:        GUI for STM32 discovery line linux programmer
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description    gui
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package -n     libstlink%{sover}
Summary:        Shared library for stlink
Group:          Development/Tools/Debuggers

%description -n libstlink%{sover}
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package        devel
Summary:        Development files for stlink package
Group:          Development/Tools/Debuggers
Requires:       libstlink%{sover} = %{version}

%description    devel
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%prep
%autosetup -p1

%build
%cmake -DSTLINK_UDEV_RULES_DIR="%_udevrulesdir" \
       -DSTLINK_MODPROBED_DIR="%_modprobedir" \
       -DCMAKE_EXE_LINKER_FLAGS="-pie"

%cmake_build

%install
%cmake_install

# remove static lib sdi
rm %{buildroot}%{_libdir}/*.a

%suse_update_desktop_file -r stlink-gui Development Debugger

%pre
# Avoid restoring outdated stuff in posttrans
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -f "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}.rpmsave.old" || :
done

%posttrans
# Migration of modprobe.conf files to _modprobedir
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -fv "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}" || :
done

%post -n libstlink%{sover} -p /sbin/ldconfig

%postun -n libstlink%{sover} -p /sbin/ldconfig

%files
%doc README.md CHANGELOG.md doc/devices_boards.md doc/tutorial.md doc/flashloaders.md
%license LICENSE.md
%{_bindir}/st-*
%{_udevrulesdir}/49-stlink*
%dir %{_modprobedir}
%{_modprobedir}/stlink_v1.conf
%{_mandir}/man1/st-flash.1*
%{_mandir}/man1/st-info.1*
%{_mandir}/man1/st-util.1*

%files -n libstlink%{sover}
%{_libdir}/libstlink.so.1*

%files gui
%{_bindir}/stlink-gui
%{_datadir}/stlink/
%{_datadir}/applications/stlink-gui.desktop
%{_datadir}/icons/hicolor/scalable/apps/stlink-gui.svg

%files devel
%dir %{_includedir}/stlink
%{_includedir}/stlink/
%{_libdir}/libstlink.so

%changelog
* Fri Mar  4 2022 Martin Wilck <mwilck@suse.com>
- Install modprobe.conf files to %%_modprobedir (bsc#1196275, jsc#SLE-20639)
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.0. Check CHANGELOG.md for the full list of changes
  + New features:
  * Extended set of cmd line arguments for st-info and st-util
  * Extended support for STM32H7 & rework of software reset
  * Added support for STM32H742/743/753
  * Official support for STLINK-V3 programmers
  * Added preliminary support for STM32L5x2
  * Option bytes on the STM32F767 ZIT6 Nucleo-144
  * Increase STM32L0 `option_size` to 20
  * st-util: Add specialized memory map for STM32H7 devices
  * Support for STM32F4 option bytes
  * ITM functionality for STLink/V2 and STM32Fxx chipsets
- Use the %%suse_update_desktop_file macro instead of
  change-desktopfile-category.patch
- Drop 0001-Fix-install-path-of-stlink-gui.ui-file.patch
* Sat Aug 29 2020 Dmitry Roshchin <dmitry_r@opensuse.org>
- Fix download link
* Sat Aug  1 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.6.1:
  + New Features:
  * Basic compatibility for STLink-v3 programmer (#271, #863, #954)
    Added support for JTAG command API v2 & distinguish protocol versions v1 and v2
    Compatibility with the STLink-v3 firmware which dropped support for the previous API v1
    As of firmware version J11 the ST-LINK-V1 programmer supports API v2 commands as well
  * Display programmer serial when no target is connected (#432, #933, #943)
  * Added connect under reset to stlink_open_usb( ) (#577, #963)
  * Support for STM32L1, SM32L4 option bytes write (#596, #844, #847)
  * Added CMAKEFLAGS and install target (#804, #935)
  * Support for STM32G4 (#822)
  * Added aliased SRAM2 region in the L496 memory map (#824)
  * Improved support for STM32G0 (#825, #850, #856, #857)
  * Added postinst script with 'depmod -a' for 'make package' (#845, #931)
  * Calculate checksums for flash operations (#862, #924)
  * Adjust the JTAG/SWD frequency via cmdline option (#893, #953)
  * Added usb PID and udev rules for STlink v2.1 found on Nucleo-L432KC and Nucleo-L552ze boards (#900)
  * STM32G0/G4 improvements (#910)
    Enable mass erase with a flash programming check
    Handle G4 Cat3 devices with configurable dual bank flash by using a helper
  + For more details, see included CHANGELOG.md
- Rebase change-desktopfile-category.patch
- Add 0001-Fix-install-path-of-stlink-gui.ui-file.patch
- Clean up spec file
* Sun Mar 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6.0:
    Added O_BINARY option to open file (#753)
    Added preliminary support for some STM32G0 chips (#759, #760)
    Added support for mass erasing second bank on STM32F10x_XL (#767)
    Added call to clear PG bit after writing to flash (#773)
    Added howto for sending NRST signal through GDB (#776)
    Added support to write option bytes for the STM32G0 (#778)
    Added simple read/write support for STM32WB55 chips (#786)
    Added STLink V3SET VID:PIDs to the udev rules (#789)
    Support for "STM32+Audio" v2-1 firmware (#790)
    Initial support for STM32L41X (#799)
    Build for Windows under Debian/Ubuntu (#802)
    Allow for 64 bytes serials (#809)
    Added support to read and write option bytes for STM32F2 series (Orie22)
    Added full support for STLINK CHIP ID L4RX (Brad Natelborg)
    Added support to write option bytes to STM32F4 devices (Davey Struijk)
    Various bug fixes
    Various translations and docs update
- Remove fix-deprecated-libusb-function.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Tue May  8 2018 stefan.bruens@rwth-aachen.de
- update to release 1.5.0
  * Chip support added for:
    + STM32F72xx73xx support (#1969148)
    + Add support of STM32L496xx/4A6xx devices (#615)
  * Fixes:
    + Fix memory map for stm32l496xx boards (#639)
    + Fix write for microcontroler with RAM size less or equal to 32K (#637)
    + Added LIB_INSTALL_DIR to correct libs install on 64-bit systems (#636)
    + Fix verification of flash error for STM32L496x device (#618)
    + Fix build on Fedora with GCC 8 (#666)
- Fix failing build due to use of deprecated libusb function:
  Add fix-deprecated-libusb-function.patch
* Tue Nov 28 2017 boris@steki.net
- update to release 1.4.0
  * Add support for STM32L452 target
  * Initial support to compile with Microsoft Visual Studio 2017
  * Added support for flashing second bank on STM32F10x_XL
  * Add support for STM32L011 target
  * Allow building of debian package with CPack
  * Add preliminary support for STM32L011 to see it after probe
  * Strip full paths to source files in log
  * Add support for STM32F413 target
  * Add support for Semihosting SYS_READC
  * Deprecation of autotools (autoconf, automake)
  * Removal of undocumented st-term utility,
    which is now replaced by st-util ARM semihosting feature
  * Add support for native debian packaging
  * Add intel hex file reading for st-flash
  * Add --reset command to st-flash
  * Support serial numbers argument for st-util
    and st-flash for multi-programmer setups
  * Add kill ('k') command to gdb-server for st-util
  * Add manpages (generated with pandoc from Markdown)
  * Rewrite commandline parsing for st-flash
  * Add support for ARM semihosting to st-util
  * Chip support added for:
    + STM32L432
    + STM32F412
    + STM32F410
    + Add memory map for STM32F401XE
    + L0x Category 5 devices
    + Add L0 Category 2 device
* Sun May  8 2016 dmitry_r@opensuse.org
- Update to version 1.2.0
  * Add multiple stlink probing (`st-info --probe`, `st-info --hla-serial`)
    with printing serial in hex and OpenOCD `hla_serial` format
  * Add stlink usb probe API functions
  * Added parameter to specify one stlink v2 of many
  * Chip support added for: STM32L053R8, STM32F7, STM32L4, F446,
    STM32F303 High Density, STM32L1xx Cat.2 devices
  * Board support added for: Nucleo-F303RE, Nucleo-F411RE
  * Minor fixes and updates
* Fri Apr  3 2015 dmitry_r@opensuse.org
- Update to version 1.1.0
  * New devices support, see included README file
  * Bugfixes
* Wed Jun 11 2014 dmitry_r@opensuse.org
- Add COPYING and README to package documentation
* Fri Jun  6 2014 dmitry_r@opensuse.org
- Initial package, version 1.0.0
